@@ -2,18 +2,39 @@ import hashlib
 import datetime as dt
 import rsa
 from cryptography.fernet import Fernet
-import pandas as pd
+#import pandas as pd
 import string
 from random import choice
+import random as rd
+import base64 as b64
 
 KEYS_RSA = rsa.newkeys(512)
 
 class LIB:
     def __init__(self):
+        #print('teste')
         pass
 
     @staticmethod
-    def token_get(word: str) -> str:
+    def base64_encrypt(word: str = ''):
+        encoded = (b64.b64encode(word.encode("ascii")))
+        encoded_ascii = encoded.decode("ascii")
+        return encoded_ascii
+
+    @staticmethod
+    def base64_decrypt(word: str):
+        decoded_ascii = None
+        try:
+            decoded = b64.b64decode(word.encode('ascii'))
+            decoded_ascii = decoded.decode('ascii')
+        except Exception as error:
+            decoded_ascii = error
+        finally:
+            return decoded_ascii
+
+
+    @staticmethod
+    def token_get(word: str = None) -> str:
         key = Fernet.generate_key()
         #f = Fernet(key)
         #token = f.encrypt(word.encode())
@@ -78,10 +99,32 @@ class LIB:
         return key
 
     @staticmethod
-    def build_keys(qtd: int = 1) -> list:
+    def build_keys(qtd: int = 1,
+                   size: int = 24,
+                   sep: str = "-",
+                   word_length: int = 4,
+                   lower_case: bool = True,
+                   upper_case: bool = True,
+                   digits: bool = True,
+                   hex_digits: bool = False,
+                   oct_digits: bool = False,
+                   special_chars: bool = False,
+                   printable_chars: bool = False,
+                   control_chars: bool = False) -> list:
         keys = []
         for index in range(qtd):
-            k = LIB.build_key()
+            k = LIB.build_key(size=size,
+                              sep=sep,
+                              word_length=word_length,
+                              lower_case=lower_case,
+                              upper_case=upper_case,
+                              digits=digits,
+                              hex_digits=hex_digits,
+                              oct_digits=oct_digits,
+                              special_chars=special_chars,
+                              printable_chars=printable_chars,
+                              control_chars=control_chars
+                              )
             keys.append(k)
         return keys
 
@@ -238,25 +281,25 @@ class LIB:
         finally:
             return result.decode()
 
-    @staticmethod
-    def get_parametros_geral(conexao) -> pd.DataFrame:
-        df = None
-        now = dt.datetime.now()
-        status = 'A' # Ativo
-        try:
-            sql = f"""
-                   SELECT *
-                     FROM Parametros
-                    where flg_status = 'A'
-                      and to_date({now.astype(str)}, "%Y-%m-%d %H:%MM:%S") between dat_ini_vigencia and dat_fim_vigencia
-                      and flg_status = '{status}'
-                    order by handle_parent, handle, num_ordem
-                   """
-            df = pd.read_sql(con=conexao, sql=sql)
-        except Exception as error:
-            df = error
-        finally:
-            return df
+    # @staticmethod
+    # def get_parametros_geral(conexao) -> pd.DataFrame:
+    #     df = None
+    #     now = dt.datetime.now()
+    #     status = 'A' # Ativo
+    #     try:
+    #         sql = f"""
+    #                SELECT *
+    #                  FROM Parametros
+    #                 where flg_status = 'A'
+    #                   and to_date({now.astype(str)}, "%Y-%m-%d %H:%MM:%S") between dat_ini_vigencia and dat_fim_vigencia
+    #                   and flg_status = '{status}'
+    #                 order by handle_parent, handle, num_ordem
+    #                """
+    #         df = pd.read_sql(con=conexao, sql=sql)
+    #     except Exception as error:
+    #         df = error
+    #     finally:
+    #         return df
 
     @staticmethod
     def get_parametro_valor(df, value) -> str:
@@ -279,25 +322,25 @@ class LIB:
         finally:
             return result
 
-    @staticmethod
-    def get_parametros_grupo(df, value) -> pd.DataFrame:
-        result = None
-        try:
-            result = df.loc[df["grupo_parametro"] == value]
-        except Exception as error:
-            result = error
-        finally:
-            return result
+    # @staticmethod
+    # def get_parametros_grupo(df, value) -> pd.DataFrame:
+    #     result = None
+    #     try:
+    #         result = df.loc[df["grupo_parametro"] == value]
+    #     except Exception as error:
+    #         result = error
+    #     finally:
+    #         return result
 
-    @staticmethod
-    def get_parametros_familia(df, value) -> pd.DataFrame:
-        result = None
-        try:
-            result = df.loc[df["familia"] == value]
-        except Exception as error:
-            result = error
-        finally:
-            return result
+    # @staticmethod
+    # def get_parametros_familia(df, value) -> pd.DataFrame:
+    #     result = None
+    #     try:
+    #         result = df.loc[df["familia"] == value]
+    #     except Exception as error:
+    #         result = error
+    #     finally:
+    #         return result
         
     @staticmethod
     def parametro_set(conexao, nom_parametro, val_parametro):
@@ -343,8 +386,13 @@ class LIB:
                  "Reset (remove formatação)": ["\033[0;0m", None]}
         return cores
 
+    @staticmethod
+    def random_generator(size: int = 6, chars: str = string.ascii_uppercase + string.digits):
+        value = ''.join(rd.choice(chars) for _ in range(size))
+        return value
+
 if __name__ == "__main__":
     x = LIB()
-    t = x.build_keys(100)
+    t = x.base64_encrypt("PagSeguro-Akron")
     print(t)
 
